@@ -1,61 +1,32 @@
 define([
     'jquery'
     , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
     , 'nbextensions/visualpython/src/common/StringBuilder'
-    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutVerticalSimple'
-    , 'nbextensions/visualpython/src/common/component/vpTableLayoutHorizontalSimple'
 
     , '../../api.js'    
-    , '../../config.js'
     , '../../constData.js'
-    , '../../blockRenderer.js'
     , '../base/index.js'
 
-], function ( $, vpCommon, vpConst, sb, vpSuggestInputText, vpTableLayoutVerticalSimple, vpTableLayoutHorizontalSimple
+], function ( $, vpCommon, sb, vpTableLayoutVerticalSimple
 
               , api
-              , config
               , constData
-              , blockRenderer
               , baseComponent ) {
 
-    const { ChangeOldToNewState
-        , FindStateValue
+    const {  CreateOneArrayValueAndGet
+            , UpdateOneArrayValueAndGet
+            , DeleteOneArrayValueAndGet
+            , GenerateExceptCode } = api;
 
-        , CreateOneArrayValueAndGet
-        , UpdateOneArrayValueAndGet
-        , DeleteOneArrayValueAndGet
-
-        , DestructureFromBlockArray
-
-        , MakeFirstCharToUpperCase
-        , MapTypeToName
-        , RemoveSomeBlockAndGetBlockList
-        , ShuffleArray
-        , GetImageUrl
-        , ControlToggleInput } = api;
-
-    const { PROCESS_MODE } = config;
-
-    const {  GenerateExceptConditionList } = blockRenderer;
-
-    const { BLOCK_DIRECTION
-            , BLOCK_CODELINE_BTN_TYPE
-            , BLOCK_CODELINE_TYPE
+    const { BLOCK_CODELINE_TYPE
 
             , IF_BLOCK_CONDITION_TYPE
             , IF_BLOCK_SELECT_VALUE_ARG_TYPE
 
-            , STR_COLON_SELECTED
-            , STR_NULL
-            , STR_FOR
-            , STR_INPUT
-            , STR_SELECTED 
+            , STR_EMPTY
             , STR_DISABLED
             , STR_CLICK
-            , STR_CHANGE
             , STR_CHANGE_KEYUP_PASTE
 
             , STR_VARIABLE
@@ -64,70 +35,43 @@ define([
             , STATE_exceptConditionList
 
             , VP_CLASS_STYLE_FLEX_ROW
-            , VP_CLASS_STYLE_FLEX_ROW_CENTER    
             , VP_CLASS_STYLE_FLEX_ROW_BETWEEN
 
-            , VP_CLASS_STYLE_WIDTH_5PERCENT
-            , VP_CLASS_STYLE_WIDTH_10PERCENT
-            , VP_CLASS_STYLE_WIDTH_15PERCENT
+
             , VP_CLASS_STYLE_WIDTH_20PERCENT
-            , VP_CLASS_STYLE_WIDTH_25PERCENT
-            , VP_CLASS_STYLE_WIDTH_30PERCENT
             , VP_CLASS_STYLE_WIDTH_35PERCENT
-            , VP_CLASS_STYLE_WIDTH_40PERCENT
-            , VP_CLASS_STYLE_WIDTH_45PERCENT
-            , VP_CLASS_STYLE_WIDTH_50PERCENT
-            , VP_CLASS_STYLE_WIDTH_55PERCENT
-            , VP_CLASS_STYLE_WIDTH_60PERCENT
-            , VP_CLASS_STYLE_WIDTH_65PERCENT
-            , VP_CLASS_STYLE_WIDTH_70PERCENT
-            , VP_CLASS_STYLE_WIDTH_75PERCENT
-            , VP_CLASS_STYLE_WIDTH_80PERCENT
-            , VP_CLASS_STYLE_WIDTH_85PERCENT
-            , VP_CLASS_STYLE_WIDTH_90PERCENT
-            , VP_CLASS_STYLE_WIDTH_95PERCENT
+
             , VP_CLASS_STYLE_WIDTH_100PERCENT
 
             , VP_CLASS_STYLE_BGCOLOR_C4C4C4
 
-            , VP_CLASS_STYLE_OPACITY_0
-            , VP_CLASS_STYLE_OPACITY_1
-
-            , VP_CLASS_STYLE_MARGIN_LEFT_15PX
-
             , VP_ID_PREFIX
             , VP_ID_APIBLOCK_OPTION_IF_ARG
             , VP_ID_APIBLOCK_OPTION_IF_ARG_1
             , VP_ID_APIBLOCK_OPTION_IF_ARG_2
             , VP_ID_APIBLOCK_OPTION_IF_ARG_3
-            , VP_ID_APIBLOCK_OPTION_IF_ARG_4
-            , VP_ID_APIBLOCK_OPTION_IF_ARG_5
-            , VP_ID_APIBLOCK_OPTION_IF_ARG_6
             , VP_ID_APIBLOCK_OPTION_IF_USER_INPUT
             , VP_ID_APIBLOCK_OPTION_IF_PLUS
             , VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT
             , VP_ID_APIBLOCK_OPTION_IF_DELETE
 
-            , COMPARISON_OPERATOR_IF_ARG2
-            , COMPARISON_OPERATOR_IF_ARG4
-            , COMPARISON_OPERATOR_IF_ARG6 } = constData;
+            , COMPARISON_OPERATOR_IF_ARG2 } = constData;
 
     const { MakeOptionContainer
             , MakeOptionDeleteButton
-            , MakeOptionPlusButton
             , MakeVpSuggestInputText_apiblock
             , MakeOptionInput } = baseComponent;
 
-    var InitIfBlockOption = function(thatBlock, optionPageSelector) {
-        var uuid = thatBlock.getUUID();
-        var blockContainerThis = thatBlock.getBlockContainerThis();
-        var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);  
+    var InitIfBlockOption = function(thisBlock, optionPageSelector) {
+        var uuid = thisBlock.getUUID();
+        var blockContainerThis = thisBlock.getBlockContainerThis();
+        var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);  
    
         /** --------------------------------- If Option 이벤트 함수 바인딩 ---------------------------------- */           
 
         /** if 변경 이벤트 함수 바인딩 */
         ifConditionListState.forEach( ( condition, index ) => {
-            var uuid = thatBlock.getUUID();
+            var uuid = thisBlock.getUUID();
             const { conditionType } = condition;
 
             // IF_BLOCK_CONDITION_TYPE
@@ -142,7 +86,7 @@ define([
                      
                      
                        
-                                var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);
+                                var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);
                                 var ifConditionState = ifConditionListState[index];
                                 var inputValue = $(this).val();
     
@@ -152,28 +96,25 @@ define([
                                         ...ifConditionState
                                         , arg1: inputValue
                                     }
-                                    // RenderInputRequiredColor(this);
+
                                 } else if (i == 2) {
                                     updatedValue = {
                                         ...ifConditionState
                                         , arg2: inputValue 
                                     }
-                                    // RenderInputRequiredColor(this);
                                 } else if (i == 3) {
                                     updatedValue = {
                                         ...ifConditionState
                                         , arg3: inputValue 
                                     }
-                                    // RenderInputRequiredColor(this);
                                 }  
     
                                 ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                                thatBlock.setState({
+                                thisBlock.setState({
                                     [STATE_exceptConditionList]: ifConditionListState
                                 });
-                                var ifConditionCode = GenerateExceptConditionList(thatBlock,BLOCK_CODELINE_TYPE.ELIF);
-                                $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-                            
+                                var ifConditionCode = GenerateExceptCode(thisBlock,BLOCK_CODELINE_TYPE.ELIF);
+                                thisBlock.writeCode(ifConditionCode);
                                 event.stopPropagation();
                             });
         
@@ -184,10 +125,8 @@ define([
                 /** If USER input 변경 이벤트 함수 바인딩 */
                 $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
                 $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid, function(event) {
-         
-                    // RenderInputRequiredColor(this);
            
-                    var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);
+                    var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);
                     var ifConditionState = ifConditionListState[index];
                     var inputValue = $(this).val();
 
@@ -198,11 +137,11 @@ define([
                
 
                     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                    thatBlock.setState({
+                    thisBlock.setState({
                         [STATE_exceptConditionList]: ifConditionListState
                     });
-                    var ifConditionCode = GenerateExceptConditionList(thatBlock,BLOCK_CODELINE_TYPE.ELIF);
-                    $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+                    var ifConditionCode = GenerateExceptCode(thisBlock,BLOCK_CODELINE_TYPE.ELIF);
+                    thisBlock.writeCode(ifConditionCode);
                 
                     event.stopPropagation();
                 });
@@ -211,7 +150,7 @@ define([
             /** 삭제 if condition */
             $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid));
             $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid), function(event) {
-                var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);
+                var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);
 
                 if (ifConditionListState.length == 1) {
                     return;
@@ -219,11 +158,11 @@ define([
                 
                 ifConditionListState = DeleteOneArrayValueAndGet(ifConditionListState, index);
 
-                thatBlock.setState({
+                thisBlock.setState({
                     [STATE_exceptConditionList]: ifConditionListState
                 });
-                var ifConditionCode = GenerateExceptConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-                $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+                var ifConditionCode = GenerateExceptCode(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+                thisBlock.writeCode(ifConditionCode);
 
                 blockContainerThis.renderBlockOptionTab();
 
@@ -235,24 +174,19 @@ define([
         $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid));
         $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid), function(event) {
 
-            var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);
-            thatBlock.addVariableIndex();
-            // var variableIndex = thatBlock.getVariableIndex();
+            var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);
             var newCondition = {
                 arg1: ''
                 , arg2: 'none'
                 , arg3: ''
-                // , arg4: 'none'
-                // , arg5: ''
-                // , arg6: ''
                 , conditionType: IF_BLOCK_CONDITION_TYPE.ARG
             }
             ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_exceptConditionList]: ifConditionListState
             });
-            var ifConditionCode = GenerateExceptConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+            var ifConditionCode = GenerateExceptCode(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+            thisBlock.writeCode(ifConditionCode);
             
             blockContainerThis.renderBlockOptionTab();
             event.stopPropagation();
@@ -262,20 +196,18 @@ define([
         $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid));
         $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid), function(event) {
 
-            var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);
-            thatBlock.addVariableIndex();
-        
+            var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);
             var newCondition = {
                 codeLine: ''
                 , arg6: ''
                 , conditionType: IF_BLOCK_CONDITION_TYPE.USER_INPUT
             }
             ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_exceptConditionList]: ifConditionListState
             });
-            var ifConditionCode = GenerateExceptConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+            var ifConditionCode = GenerateExceptCode(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+            thisBlock.writeCode(ifConditionCode);
             
             blockContainerThis.renderBlockOptionTab();
             event.stopPropagation();
@@ -283,7 +215,7 @@ define([
 
         /** arg1, arg2, arg3, arg4, arg5, arg6 select 변경 if condition */
         var bindSelectValueEventFunc_if = function(selectedValue, index, type) {
-            var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);
+            var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);
             var ifConditionState = ifConditionListState[index];
             var updatedValue;
             if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG1) {
@@ -291,13 +223,12 @@ define([
                     ...ifConditionState
                     , arg1: selectedValue 
                 }
-                // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid, selectedValue);
             } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2) {
                 updatedValue = {
                     ...ifConditionState
                     , arg2: selectedValue 
                 }
-                if (selectedValue == 'none' || selectedValue == STR_NULL) {
+                if (selectedValue == 'none' || selectedValue == STR_EMPTY) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).attr(STR_DISABLED, true);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
@@ -307,24 +238,19 @@ define([
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).attr(STR_DISABLED, false);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                 } 
-                // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid, selectedValue);
             } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3) {
                 updatedValue = {
                     ...ifConditionState
                     , arg3: selectedValue 
                 }
-                // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid, selectedValue);
             } 
 
             ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_exceptConditionList]: ifConditionListState
             });
-            var ifConditionCode = GenerateExceptConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-
-
-            // blockContainerThis.renderBlockOptionTab();
+            var ifConditionCode = GenerateExceptCode(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+            thisBlock.writeCode(ifConditionCode);
         }
 
         /** --------------------------------- Else Option 이벤트 함수 바인딩 ---------------------------------- */  
@@ -343,12 +269,10 @@ define([
 
         /** If option 렌더링 */
         var renderThisComponent = function() {
-            var optionContainerDom = MakeOptionContainer();
+            var optionContainerDom = MakeOptionContainer(thisBlock);
             /* --------------------------- if ----------------------------- */
             var loadedVariableNameList = blockContainerThis.getKernelLoadedVariableNameList();
-            var variableIndex = thatBlock.getVariableIndex();
-
-            var ifConditionListState = thatBlock.getState(STATE_exceptConditionList);   
+            var ifConditionListState = thisBlock.getState(STATE_exceptConditionList);   
             ifConditionListState.forEach( (condition, index) => {
      
                 const { conditionType } = condition; 
@@ -403,12 +327,9 @@ define([
                     sbConditionLeft.appendLine(suggestInputArg1);
                     sbConditionLeft.appendLine(suggestInputArg2);
                     sbConditionLeft.appendLine(suggestInputArg3);
-                    // sbConditionLeft.appendLine(suggestInputArg4);
-                    // sbConditionLeft.appendLine(suggestInputArg5);
+          
                     sbConditionLeft.appendLine("</div>");
-
                     sbCondition.appendLine(sbConditionLeft.toString());
-                    // sbCondition.appendLine(suggestInputArg6);
 
                     var deleteConditionButton = MakeOptionDeleteButton(VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid);
                     sbCondition.appendLine(deleteConditionButton);
@@ -443,11 +364,6 @@ define([
             sbButtonContainer.appendLine("</div>");
             var sbButtonContainerDom = $(sbButtonContainer.toString());
 
-            // var plusButton = MakeOptionPlusButton(VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid, '+ Condition');
-            // var plusButton_userInput = MakeOptionPlusButton(VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid, '+ User Input', VP_CLASS_STYLE_MARGIN_LEFT_15PX);
-            // sbButtonContainerDom.append(plusButton);
-            // sbButtonContainerDom.append(plusButton_userInput);
-
             optionContainerDom.append(sbButtonContainerDom);
             /** bottom block option 탭에 렌더링된 dom객체 생성 */
             $(optionPageSelector).append(optionContainerDom);
@@ -466,7 +382,7 @@ define([
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(arg2);
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).val(arg3);
    
-                if (arg2 == 'none' || arg2 == STR_NULL) {
+                if (arg2 == 'none' || arg2 == STR_EMPTY) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).attr(STR_DISABLED, true);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
@@ -476,19 +392,13 @@ define([
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).attr(STR_DISABLED, false);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                 } 
-  
 
-      
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid);
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid);
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid);
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid);
-
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
             });
+
+            return optionContainerDom;
         }
 
-        renderThisComponent();
+        return renderThisComponent();
     }
 
     return InitIfBlockOption;
