@@ -513,7 +513,5 @@ define([
         return rootDom;
     }
 
-    return {VpXMLHandler: VpXMLHandler
-            , xmlToJson: xmlToJson
-            , xmlToArray: xmlToArray };
+    return { VpXMLHandler: VpXMLHandler };
 });
\ No newline at end of file
