@@ -203,8 +203,44 @@ define([
             } else if (menu == 'default-snippets') {
                 // import default snippets
                 var defaultSnippets = {
-                    'default import': 'import numpy as np\nimport pandas as pd\nimport matplotlib.pyplot as plt\n%matplotlib inline\nimport seaborn as sns'
+                    'default import': [
+                        'import numpy as np',
+                        'import pandas as pd',
+                        'import matplotlib.pyplot as plt',
+                        '%matplotlib inline',
+                        'import seaborn as sns',
+                        'import plotly.express as px'
+                    ],
+                    'as_float': [
+                        'def as_float(x):',
+                        '    """',
+                        "    usage: df['col'] = df['col'].apply(as_float)",
+                        '    """',
+                        '    if not isinstance(x, str):',
+                        '        return 0.0',
+                        '    else:',
+                        '        try:',
+                        '        result = float(x)',
+                        '            return result',
+                        '        except ValueError:',
+                        '            return 0.0'
+                    ],
+                    'as_int': [
+                        'def as_int(x):',
+                        '    """',
+                        "    usage: df['col'] = df['col'].apply(as_int)",
+                        '    """',
+                        '    if not isinstance(x, str):',
+                        '        return 0',
+                        '    else:',
+                        '        try:',
+                        '            result = int(x)',
+                        '            return result',
+                        '        except ValueError:',
+                        '            return 0.0'
+                    ]
                 }
+
                 var timestamp = new Date().getTime();
 
                 var keys = Object.keys(defaultSnippets);
@@ -218,7 +254,8 @@ define([
                         importKey = key + '_imported' + importNo;
                         importNo += 1;
                     }
-                    var newSnippet = { [importKey]: { code: defaultSnippets[key], timestamp: timestamp } };
+                    var code = defaultSnippets[key].join('\n');
+                    var newSnippet = { [importKey]: { code: code, timestamp: timestamp } };
                     vpSetting.saveUserDefinedCode(newSnippet);
 
                     importKeys.push(importKey);
@@ -229,6 +266,7 @@ define([
 
                 vpCommon.renderSuccessMessage('Default snippets imported');
             }
+            evt.stopPropagation();
         });
 
         // search item 
@@ -312,9 +350,9 @@ define([
                     var parent = $(thisHeader).parent();
                     var indicator = $(thisHeader).find('.vp-sn-indicator');
                     var hasOpen = $(indicator).hasClass('open');
-                    // hide all codebox
-                    $(that.wrapSelector('.vp-sn-indicator')).removeClass('open');
-                    $(that.wrapSelector('.vp-sn-item-code')).hide();
+                    // Deprecated: hide all codebox
+                    // $(that.wrapSelector('.vp-sn-indicator')).removeClass('open');
+                    // $(that.wrapSelector('.vp-sn-item-code')).hide();
                     
                     if (that.clicked > 1 || !hasOpen) {
                         // show code
@@ -322,6 +360,7 @@ define([
                         $(parent).find('.vp-sn-item-code').show();
                     } else {
                         // hide code
+                        $(indicator).removeClass('open');
                         $(parent).find('.vp-sn-item-code').hide();
                     }
                     that.clicked = 0;
@@ -378,19 +417,19 @@ define([
         // item menu click
         $(document).on('click', this.wrapSelector('.vp-sn-item-menu-item'), function(evt) {
             var menu = $(this).data('menu');
-            var title = $(this).closest('.vp-sn-item').data('title');
+            var item = $(this).closest('.vp-sn-item');
+            var title = $(item).data('title');
             if (menu == 'run') {
-                var item = $(this).closest('.vp-sn-item');
-                var title = $(item).data('title');
-
                 // get codemirror
                 that.codemirrorList[title].save();
                 var code = that.codemirrorList[title].getValue();
                 $(vpCommon.wrapSelector('#vp_appsCode')).val(code);
                 $(vpCommon.wrapSelector('#vp_appsCode')).trigger({
-                    type: 'popup_apply',
+                    type: 'popup_run',
                     title: 'Snippets',
-                    code: code 
+                    code: code,
+                    addCell: true,
+                    runCell: true
                 });
             } else if (menu == 'duplicate') {
                 var dupNo = 1;
@@ -433,7 +472,20 @@ define([
                     that.loadUdfList();
                 }
                 
+            } else if (menu == 'save') {
+                var codemirror = that.codemirrorList[title];
+                codemirror.save();
+                var code = codemirror.getValue();
+                
+                // save changed code
+                var timestamp = new Date().getTime();
+                var updateSnippet = { [title]: { code: code, timestamp: timestamp } };
+                vpSetting.saveUserDefinedCode(updateSnippet);
+
+                // hide it
+                $(this).hide();
             }
+            evt.stopPropagation();
         });
 
         //////////////// export mode ///////////////////////
@@ -584,7 +636,7 @@ define([
         item.appendLine('</div>');
         item.appendFormatLine('<div class="{0}" data-menu="{1}" title="{2}">'
                             , 'vp-sn-item-menu-item', 'delete', 'Delete');
-        item.appendFormatLine('<img src="{0}"/>', '/nbextensions/visualpython/resource/snippets/delete.svg');
+        item.appendFormatLine('<img src="{0}"/>', '/nbextensions/visualpython/resource/delete.svg');
         item.appendLine('</div>'); 
         item.appendLine('</div>'); // end of vp-sn-item-menu
         // export mode checkbox
@@ -592,6 +644,10 @@ define([
         item.appendLine('</div>'); // end of vp-sn-item-header
         item.appendFormatLine('<div class="{0}">', 'vp-sn-item-code');
         item.appendFormatLine('<textarea>{0}</textarea>', code);
+        item.appendFormatLine('<div class="{0} {1}" data-menu="{2}" title="{3}">', 'vp-sn-item-menu-item', 'vp-sn-save', 'save', 'Save changes');
+        item.appendFormatLine('<img src="{0}"/>', '/nbextensions/visualpython/resource/snippets/save_orange.svg');
+        // item.appendFormatLine('<object class="{0}" type="image/svg+xml" data="{1}" width="20" height="20"></object>', 'vp-sn-saveimg', '/nbextensions/visualpython/resource/snippets/save_gray2.svg');
+        item.appendLine('</div>'); // vp-sn-save
         item.appendLine('</div>'); // end of vp-sn-item-code
         item.appendLine('</div>'); // end of vp-sn-item
         return item.toString();
@@ -656,14 +712,17 @@ define([
         // bind code change
         // item code save
         codemirror.on('change', function() {
-            var title = $(tag).closest('.vp-sn-item').data('title');
-            codemirror.save();
-            var code = codemirror.getValue();
+            // var title = $(tag).closest('.vp-sn-item').data('title');
+            // codemirror.save();
+            // var code = codemirror.getValue();
             
-            // save changed code
-            var timestamp = new Date().getTime();
-            var updateSnippet = { [title]: { code: code, timestamp: timestamp } };
-            vpSetting.saveUserDefinedCode(updateSnippet);
+            // // save changed code
+            // var timestamp = new Date().getTime();
+            // var updateSnippet = { [title]: { code: code, timestamp: timestamp } };
+            // vpSetting.saveUserDefinedCode(updateSnippet);
+
+            // show save button
+            $(tag).parent().find('.vp-sn-save').show();
         });
     }
 
