@@ -268,8 +268,8 @@ define([
     const STR_INPUT_NUMBER = 'input number';
     const STR_INPUT_VARIABLE = 'input variable';
 
-    const STR_INPUT_NUMBER_KOR = '숫자 입력';
-    const STR_INPUT_VARIABLE_KOR = '변수 입력';
+    const STR_INPUT_NUMBER_KOR = 'Input Number';
+    const STR_INPUT_VARIABLE_KOR = 'Input Variable';
 
     const STR_CHANGE_KEYUP_PASTE = 'change keyup paste';
 
