@@ -48,7 +48,7 @@ define([], function() {
                 {
                     type: ['var'],
                     var_type: ['Series'],
-                    label: 'return variable'
+                    label: 'Return to'
                 }
             ]
         },
@@ -82,7 +82,7 @@ define([], function() {
                 {
                     type: ['var'],
                     var_type: ['DataFrame'],
-                    label:'return variable'
+                    label:'Return to'
                 }
             ]
         },
@@ -131,7 +131,7 @@ define([], function() {
                 {
                     type: ['var'],
                     var_type: ['Index'],
-                    label:'return variable'
+                    label:'Return to'
                 }
             ]
         },
