@@ -22,7 +22,9 @@ define([
 
     const FILE_NAVIGATION_TYPE = {
         SAVE_FILE: 'SAVE_FILE',
-        READ_IMG_FOR_MARKDOWN: 'READ_IMG_FOR_MARKDOWN'
+        READ_IMG_FOR_MARKDOWN: 'READ_IMG_FOR_MARKDOWN',
+        SAVE_SNIPPETS: 'SAVE_SNIPPETS',
+        READ_SNIPPETS: 'READ_SNIPPETS'
     }
 
     /**
